@@ -1,8 +1,7 @@
 import pandas as pd
-from matminer.data_retrieval.retrieve_base import BaseDataRetrieval
+from pymatgen.ext.matproj import MPRester, MPRestError
 
-from pymatgen.ext.matproj import MPRester
-from pymatgen.ext.matproj import MPRestError
+from matminer.data_retrieval.retrieve_base import BaseDataRetrieval
 
 __author__ = [
     "Saurabh Bajaj <sbajaj@lbl.gov>",
@@ -119,7 +118,7 @@ class MPDataRetrieval(BaseDataRetrieval):
             If the target property is not available for a certain material_id,
             NaN is returned.
         """
-        method = getattr(self.mprester, "get_{}_by_material_id".format(prop))
+        method = getattr(self.mprester, f"get_{prop}_by_material_id")
         props = []
         for material_id in material_id_list:
             try:
